@@ -72,11 +72,11 @@ async fn unmark_owned(graph: Arc<Graph>,principal :Principal) {
        ).await.unwrap();
    let mut worked = false;
    if let Ok(Some(row)) = result.next().await {
-       if let Some(true) = row.get::<bool>("n.owned"){
+       if let Some(false) = row.get::<bool>("n.owned"){
            worked = true;
        }
    } 
-   println!("unmarked {} as owned: {}",&principal,worked);
+   println!("{} unmarked: {}",&principal,worked);
 }
 
 /// marks the provided principal as owned
@@ -97,7 +97,8 @@ async fn mark_owned(graph: Arc<Graph>,principal :Principal) {
            worked = true;
        }
    } 
-   println!("marked {} as owned: {}",&principal,worked);
+
+   println!("{}{}{}",&principal," ",worked);
 }
 
 /// determines if the provided principals argument was supposed to represent
@@ -230,7 +231,8 @@ async fn main() {
            get_local_admins_with_creds(graph_rc,principal).await;
        }
    } else {
-       eprintln!("no command was provided");
+       for p in &principals { println!("{}",p);}
+       eprintln!("no command was provided, above is what was parsed");
    }
 
    futures::future::join_all(handles).await;
